<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dump?lang_cible=en
// ** ne pas modifier le fichier **

return [

	// D
	'dump_description' => 'Backup and restoration of the database in SQLite format',
	'dump_slogan' => 'Backup and restore database SPIP',
];
